@@ -5,6 +5,7 @@ from django.utils.unittest import skipIf
 from django.test.utils import override_settings
 from django.conf import settings
 
+from rq import get_current_job, Queue
 from rq.job import Job
 
 from django_rq.decorators import job
@@ -14,7 +15,7 @@ from django_rq.workers import get_worker
 
 try:
     from rq_scheduler import Scheduler
-    from .queues import get_scheduler
+    from ..queues import get_scheduler
     RQ_SCHEDULER_INSTALLED = True
 except ImportError:
     RQ_SCHEDULER_INSTALLED = False
@@ -23,6 +24,11 @@ except ImportError:
 QUEUES = settings.RQ_QUEUES
 
 
+def access_self():
+    job = get_current_job()
+    return job.id
+
+
 class QueuesTest(TestCase):
 
     def test_get_connection_default(self):
@@ -176,6 +182,18 @@ class WorkersTest(TestCase):
         queue = w.queues[0]
         self.assertEqual(queue.name, 'test')
 
+    def test_get_current_job(self):
+        """
+        Ensure that functions using RQ's ``get_current_job`` doesn't fail
+        when run from rqworker (the job id is not in the failed queue).
+        """
+        queue = get_queue()
+        job = queue.enqueue(access_self)
+        call_command('rqworker', burst=True)
+        failed_queue = Queue(name='failed', connection=queue.connection)
+        self.assertFalse(job.id in failed_queue.job_ids)
+
+
 
 class SchedulerTest(TestCase):
 
